@@ -12,12 +12,12 @@ IsingSumLikelihood <- function(graph, thresholds, beta, responses = c(0L,1L))
   P <- exp(- beta * apply(Allstates,1,function(s)H(graph,s,thresholds)))
   SumScores <- rowSums(1*(Allstates==1))
 
-  df <- ddply(data.frame(Sum = SumScores, P = P),"Sum",summarize,P=sum(P))
+  df <- plyr::ddply(data.frame(Sum = SumScores, P = P),"Sum",plyr::summarize,P=sum(P))
   df$P <- df$P / sum(df$P)
   return(df)
 }
 
-IsingLikelihood <- function(graph, thresholds, beta, responses = c(0L,1L))
+IsingLikelihood <- function(graph, thresholds, beta, responses = c(0L,1L), potential = FALSE)
 {
   stopifnot(isSymmetric(graph))  
   stopifnot(length(responses)==2)
@@ -29,7 +29,12 @@ IsingLikelihood <- function(graph, thresholds, beta, responses = c(0L,1L))
   N <- nrow(graph)
   Allstates <- do.call(expand.grid,lapply(1:N,function(x)c(responses[1],responses[2])))
   P <- exp(- beta * apply(Allstates,1,function(s)H(graph,s,thresholds)))
-  df <- cbind(Probability = P / sum(P), Allstates)
+  if (potential){
+    df <- cbind(Potential = P, Allstates)    
+  } else {
+    df <- cbind(Probability = P / sum(P), Allstates)
+  }
+
   return(df)
 }
 
